pub enum FoundFontSource {
Path(PathBuf),
Bytes(Arc<[u8]>),
}Expand description
Font bytes source resolved from the system font database.
Path points to an on-disk font file.
Bytes contains the font data copied into memory (can be large).
Variants